@@ -17,19 +17,19 @@
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
-#include <ntqlayout.h>
-#include <ntqcheckbox.h>
-#include <ntqtooltip.h>
-#include <ntqwhatsthis.h>
-#include <ntqlistview.h>
-#include <ntqlabel.h>
-#include <ntqregexp.h>
-#include <ntqpushbutton.h>
-#include <ntqpopupmenu.h>
-#include <ntqtabwidget.h>
-#include <ntqcombobox.h>
-#include <ntqtimer.h>
-#include <ntqlineedit.h>
+#include <tqlayout.h>
+#include <tqcheckbox.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
+#include <tqlistview.h>
+#include <tqlabel.h>
+#include <tqregexp.h>
+#include <tqpushbutton.h>
+#include <tqpopupmenu.h>
+#include <tqtabwidget.h>
+#include <tqcombobox.h>
+#include <tqtimer.h>
+#include <tqlineedit.h>
 
 #include <tdelocale.h>
 #include <kdebug.h>
@@ -39,23 +39,23 @@
 #include <tdeconfig.h>
 #include <twin.h>
 
-#include <entry.h>
-#include <entryfield.h>
-#include <file.h>
-#include <settings.h>
-#include <entrywidgettab.h>
-#include <entrywidgettitle.h>
-#include <entrywidgetauthor.h>
-#include <entrywidgetkeyword.h>
-#include <entrywidgetpublication.h>
-#include <entrywidgetmisc.h>
-#include <entrywidgetexternal.h>
-#include <entrywidgetuserdefined.h>
-#include <entrywidgetother.h>
-#include <entrywidgetwarningsitem.h>
-#include <fieldlistview.h>
-#include <idsuggestions.h>
-#include <webqueryarxiv.h>
+#include "entry.h"
+#include "entryfield.h"
+#include "file.h"
+#include "settings.h"
+#include "entrywidgettab.h"
+#include "entrywidgettitle.h"
+#include "entrywidgetauthor.h"
+#include "entrywidgetkeyword.h"
+#include "entrywidgetpublication.h"
+#include "entrywidgetmisc.h"
+#include "entrywidgetexternal.h"
+#include "entrywidgetuserdefined.h"
+#include "entrywidgetother.h"
+#include "entrywidgetwarningsitem.h"
+#include "fieldlistview.h"
+#include "idsuggestions.h"
+#include "webqueryarxiv.h"
 #include "entrywidget.h"
 
 namespace KBibTeX
