@@ -17,15 +17,15 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-#include <ntqlayout.h>
-#include <ntqlabel.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
 
 #include <kdebug.h>
 #include <kdialog.h>
 #include <kiconloader.h>
 #include <tdelocale.h>
 
-#include <settings.h>
+#include "settings.h"
 #include "entrywidgetuserdefined.h"
 
 namespace KBibTeX
