@@ -17,14 +17,14 @@
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
-#include <file.h>
-#include <element.h>
-#include <entry.h>
-#include <macro.h>
-#include <preamble.h>
-#include <value.h>
-#include <comment.h>
-#include <encoderlatex.h>
+#include "file.h"
+#include "element.h"
+#include "entry.h"
+#include "macro.h"
+#include "preamble.h"
+#include "value.h"
+#include "comment.h"
+#include "encoderlatex.h"
 
 #include "fileexporterbibtex.h"
 
