@@ -17,18 +17,18 @@
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
-#include <ntqlabel.h>
-#include <ntqlayout.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
 
 #include <klineedit.h>
 #include <kdialogbase.h>
 #include <tdelocale.h>
 #include <kdebug.h>
 
-#include <element.h>
-#include <fileexporterbibtex.h>
-#include <fileimporterbibtex.h>
-#include <fieldlineedit.h>
+#include "element.h"
+#include "fileexporterbibtex.h"
+#include "fileimporterbibtex.h"
+#include "fieldlineedit.h"
 
 #include "macrowidget.h"
 
