@@ -17,18 +17,18 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-#include <ntqfile.h>
-#include <ntqbuffer.h>
-#include <ntqspinbox.h>
+#include <tqfile.h>
+#include <tqbuffer.h>
+#include <tqspinbox.h>
 
 #include <tdelocale.h>
 #include <klineedit.h>
 #include <tdemessagebox.h>
 #include <kurl.h>
 
-#include <fileimporterbibtex.h>
-#include <encoderxml.h>
-#include <settings.h>
+#include "fileimporterbibtex.h"
+#include "encoderxml.h"
+#include "settings.h"
 #include "webqueryarxiv.h"
 
 namespace KBibTeX
